@@ -1,7 +1,13 @@
+# Copyright 2025 © BeeAI a Series of LF Projects, LLC
+# SPDX-License-Identifier: Apache-2.0
+
 from enum import Enum
+from typing import Optional
 
 from pydantic import BaseModel
 
+from acp_sdk.models.common import AnyModel
+
 
 class ErrorCode(str, Enum):
     SERVER_ERROR = "server_error"
@@ -10,8 +16,9 @@ class ErrorCode(str, Enum):
 
 
 class Error(BaseModel):
-    code: ErrorCode
+    code: ErrorCode | str  # Allow arbitrary string for backwards compatibility
     message: str
+    data: Optional[AnyModel] = None
 
 
 class ACPError(Exception):
