@@ -1,3 +1,6 @@
+# Copyright 2025 © BeeAI a Series of LF Projects, LLC
+# SPDX-License-Identifier: Apache-2.0
+
 import asyncio
 import uuid
 from collections.abc import AsyncIterator
@@ -6,17 +9,15 @@ from enum import Enum
 from typing import Any, Literal, Optional, Union
 
 from pydantic import AnyUrl, BaseModel, ConfigDict, Field
+from pydantic.json_schema import SkipJsonSchema
 
+from acp_sdk.models.common import AnyModel
 from acp_sdk.models.errors import ACPError, Error
 from acp_sdk.models.platform import PlatformUIAnnotation
 from acp_sdk.models.types import AgentName, ResourceUrl, RunId, SessionId
 from acp_sdk.shared import ResourceLoader, ResourceStore
 
 
-class AnyModel(BaseModel):
-    model_config = ConfigDict(extra="allow")
-
-
 class Author(BaseModel):
     name: str
     email: str | None = None
@@ -110,11 +111,38 @@ class CitationMetadata(BaseModel):
     """
 
     kind: Literal["citation"] = "citation"
-    start_index: Optional[int]
-    end_index: Optional[int]
-    url: Optional[str]
-    title: Optional[str]
-    description: Optional[str]
+    start_index: Optional[int] = None
+    end_index: Optional[int] = None
+    url: Optional[str] = None
+    title: Optional[str] = None
+    description: Optional[str] = None
+
+
+class TrajectoryMetadata(BaseModel):
+    """
+    Represents trajectory information for an agent's reasoning or tool execution
+    steps. This metadata helps track the agent's decision-making process and
+    provides transparency into how the agent arrived at its response.
+
+    TrajectoryMetadata can capture either:
+    1. A reasoning step with a message
+    2. A tool execution with tool name, input, and output
+
+    This information can be used for debugging, audit trails, and providing
+    users with insight into the agent's thought process.
+
+    Properties:
+    - message: A reasoning step or thought in the agent's decision process.
+    - tool_name: Name of the tool that was executed.
+    - tool_input: Input parameters passed to the tool.
+    - tool_output: Output or result returned by the tool.
+    """
+
+    kind: Literal["trajectory"] = "trajectory"
+    message: Optional[str] = None
+    tool_name: Optional[str] = None
+    tool_input: Optional[AnyModel] = None
+    tool_output: Optional[AnyModel] = None
 
 
 class MessagePart(BaseModel):
@@ -126,7 +154,7 @@ class MessagePart(BaseModel):
 
     model_config = ConfigDict(extra="allow")
 
-    metadata: Optional[CitationMetadata] = Field(discriminator="kind", default=None)
+    metadata: Optional[CitationMetadata | TrajectoryMetadata] = Field(discriminator="kind", default=None)
 
     def model_post_init(self, __context: Any) -> None:
         if self.content is not None and self.content_url is not None:
@@ -325,10 +353,20 @@ Event = Union[
 ]
 
 
+class InputContentTypes(BaseModel):
+    types: list[str]
+
+
+class OutputContentTypes(BaseModel):
+    types: list[str]
+
+
 class AgentManifest(BaseModel):
     name: str
     description: str | None = None
     metadata: Metadata = Metadata()
+    input_content_types: list[str] = Field(default_factory=lambda: ["*/*"])
+    output_content_types: list[str] = Field(default_factory=lambda: ["*/*"])
 
 
 class Session(BaseModel):
@@ -336,8 +374,8 @@ class Session(BaseModel):
     history: list[ResourceUrl] = Field(default_factory=list)
     state: ResourceUrl | None = None
 
-    loader: ResourceLoader | None = Field(None, exclude=True)
-    store: ResourceStore | None = Field(None, exclude=True)
+    loader: SkipJsonSchema[ResourceLoader | None] = Field(None, exclude=True)
+    store: SkipJsonSchema[ResourceStore | None] = Field(None, exclude=True)
 
     model_config = ConfigDict(arbitrary_types_allowed=True)
 
