@@ -1,3 +1,6 @@
+# Copyright 2025 © BeeAI a Series of LF Projects, LLC
+# SPDX-License-Identifier: Apache-2.0
+
 import asyncio
 from collections.abc import AsyncGenerator
 from concurrent.futures import ThreadPoolExecutor
@@ -13,6 +16,7 @@ from fastapi.encoders import jsonable_encoder
 from fastapi.middleware.cors import CORSMiddleware
 from fastapi.responses import JSONResponse, StreamingResponse
 from obstore.exceptions import NotFoundError
+from pydantic import AnyHttpUrl, ValidationError
 
 from acp_sdk.models import (
     ACPError,
@@ -67,8 +71,10 @@ def create_app(
     resource_store: ResourceStore | None = None,
     resource_loader: ResourceLoader | None = None,
     forward_resources: bool = True,
+    forward_base_url: AnyHttpUrl | str | None = None,
     lifespan: Lifespan[AppType] | None = None,
     dependencies: list[Depends] | None = None,
+    enable_playground_cors: bool = True,
 ) -> FastAPI:
     if not forward_resources and (
         resource_store is None
@@ -76,6 +82,12 @@ def create_app(
     ):
         raise ValueError("Resource forwarding must be enabled when resource store does not support HTTP URLs")
 
+    if isinstance(forward_base_url, str):
+        try:
+            forward_base_url = AnyHttpUrl(forward_base_url)
+        except ValidationError:
+            raise ValueError("forward_base_url must be a valid http(s) url")
+
     executor: ThreadPoolExecutor
     client = httpx.AsyncClient()
 
@@ -96,13 +108,14 @@ def create_app(
         dependencies=dependencies,
     )
 
-    app.add_middleware(
-        CORSMiddleware,
-        allow_origins=["https://agentcommunicationprotocol.dev"],
-        allow_methods=["*"],
-        allow_headers=["*"],
-        allow_credentials=True,
-    )
+    if enable_playground_cors:
+        app.add_middleware(
+            CORSMiddleware,
+            allow_origins=["https://agentcommunicationprotocol.dev"],
+            allow_methods=["*"],
+            allow_headers=["*"],
+            allow_credentials=True,
+        )
 
     agents: dict[AgentName, AgentManifest] = {agent.name: agent for agent in agents}
 
@@ -141,7 +154,13 @@ def create_app(
     async def list_agents() -> AgentsListResponse:
         return AgentsListResponse(
             agents=[
-                AgentModel(name=agent.name, description=agent.description, metadata=agent.metadata)
+                AgentModel(
+                    name=agent.name,
+                    description=agent.description,
+                    metadata=agent.metadata,
+                    input_content_types=agent.input_content_types,
+                    output_content_types=agent.output_content_types,
+                )
                 for agent in agents.values()
             ]
         )
@@ -149,7 +168,13 @@ def create_app(
     @app.get("/agents/{name}")
     async def read_agent(name: AgentName) -> AgentReadResponse:
         agent = find_agent(name)
-        return AgentModel(name=agent.name, description=agent.description, metadata=agent.metadata)
+        return AgentModel(
+            name=agent.name,
+            description=agent.description,
+            metadata=agent.metadata,
+            input_content_types=agent.input_content_types,
+            output_content_types=agent.output_content_types,
+        )
 
     @app.get("/ping")
     async def ping() -> PingResponse:
@@ -165,6 +190,10 @@ def create_app(
         def create_resource_url_forwarded(id: ResourceId) -> ResourceUrl:
             if not forward_resources:
                 raise RuntimeError("Resource forwarding disabled")
+            if forward_base_url:
+                return ResourceUrl(
+                    url=str(app.url_path_for("get_resource", resource_id=id).make_absolute_url(str(forward_base_url)))
+                )
             return ResourceUrl(url=str(req.url_for("get_resource", resource_id=id)))
 
         async def create_resource_url(id: ResourceId) -> ResourceUrl:
