@@ -1,3 +1,6 @@
+# Copyright 2025 © BeeAI a Series of LF Projects, LLC
+# SPDX-License-Identifier: Apache-2.0
+
 import asyncio
 from collections.abc import AsyncIterator
 from typing import Generic
@@ -37,4 +40,4 @@ class RedisStore(Store[T], Generic[T]):
                     yield await self.get(key)
         finally:
             await pubsub.unsubscribe(channel)
-            await pubsub.close()
+            await pubsub.aclose()
